Skip to contents

A function in the metab_model_interface. Returns the internal model representation as fitted to the supplied data and arguments.

Usage

get_fit(metab_model)

# S3 method for class 'metab_model'
get_fit(metab_model)

Arguments

metab_model

A metabolism model that implements the metab_model_interface.

Value

An internal model representation, which may have any class.

Methods (by class)

  • get_fit(metab_model): This implementation is shared by many model types

Examples

get_fit(metab_model(fit = list(converged = TRUE)))
#> $converged
#> [1] TRUE
#>