If a log file was created during a model run, this function can retrieve it.
Methods (by class)
get_log(metab_bayes): If a log file was created during the Bayesian MCMC run, metab_bayes() attempted to capture it. Retrieve what was captured with this function.
Examples
mm <- metab_model("metab_bayes", log = "Sampling complete")
get_log(mm)
#> Sampling complete