This function has been replaced by lookup_timezone(), which uses
the lutz package for offline timezone lookup instead of the Google API.
This function has been replaced by lookup_timezone(), which uses
the lutz package for offline timezone lookup instead of the Google API.