Skip to contents

Describe the requirements for an argument to metab()

Usage

metab_inputs(
  type = c("bayes", "mle", "night", "Kmodel", "sim"),
  input = c("specs", "data", "data_daily", "info")
)

Arguments

type

The type of model you want to fit.

input

The name of an argument to pass into metab().

Value

For data and data_daily, a tibble describing the required columns when the selected model accepts that input. Otherwise, returns NULL invisibly after displaying guidance with cli::cli_inform().

Examples

metab_inputs('night','specs')
#>  Use `specs(mm_name('night'))`.
#>  See `mm_name()` (`?streamMetabolizer::mm_name()`) and `specs()`
#>   (`?streamMetabolizer::specs()`) for more options.
metab_inputs('bayes','data')
#> # A tibble: 7 × 4
#>   colname    class          units          need    
#>   <chr>      <chr>          <chr>          <chr>   
#> 1 solar.time POSIXct,POSIXt ""             required
#> 2 DO.obs     numeric        "mgO₂ L⁻¹"     required
#> 3 DO.sat     numeric        "mgO₂ L⁻¹"     required
#> 4 depth      numeric        "m"            required
#> 5 temp.water numeric        "°C"           required
#> 6 light      numeric        "µmol m⁻² s⁻¹" required
#> 7 discharge  numeric        "m³ s⁻¹"       optional
metab_inputs('Kmodel','data_daily')
#> # A tibble: 6 × 4
#>   colname          class   units    need    
#>   <chr>            <chr>   <chr>    <chr>   
#> 1 date             Date    ""       required
#> 2 K600.daily       numeric "d⁻¹"    required
#> 3 K600.daily.lower numeric "d⁻¹"    optional
#> 4 K600.daily.upper numeric "d⁻¹"    optional
#> 5 discharge.daily  numeric "m³ s⁻¹" optional
#> 6 velocity.daily   numeric "m s⁻¹"  optional
metab_inputs('mle','info')
#>  `info` is optional metadata stored in the returned `metab_model()`
#>   (`?streamMetabolizer::metab_model()`).
#>  Use `NULL` (the default) or any R object, then retrieve it with `get_info()`
#>   (`?streamMetabolizer::get_info()`).