Check the syntactic & scientific validity of a model name. Returns the model name if it's valid, otherwise gives an error
Arguments
- model_name
Character string identifying the model features. Use
mm_name()to create a valid name based on desired attributes, ormm_valid_names()to see all valid names. Two alternatives to the names given bymm_valid_names()are also accepted: (1) a model type as accepted by thetypeargument tomm_name, which will be used to create the default model name for that model type, or (2) a full model file path for custom Bayesian models, as long as basename(model_name) can still be parsed correctly withmm_parse_name()and the file exists. In that case the file may be specified either as a file path relative to the streamMetabolizer models directory (the first assumption; this directory can be found withsystem.file("models", package="streamMetabolizer")) or as an absolute path or a path relative to the current working directory (the second assumption, if the first assumption turns up no files of the given name).
Examples
mm_validate_name("b_np_oipi_tr_plrckm.stan")
#> [1] "b_np_oipi_tr_plrckm.stan"
try(mm_validate_name("b_np_oipn"))
#> Error in mm_validate_name("b_np_oipn") :
#> Could not parse model name "b_np_oipn".
#> ℹ Construct the name with `mm_name()`.