Plots modeled values as lines, observed values as points
Arguments
- metab_preds
A data.frame of predictions such as that returned by predict_metab().
- y_var
Character. Should the plot display predicted values of GPP and/or ER? The default is to plot both.
- style
Character indicating which graphics package to use.
- y_lim
List of named vectors, each of which has length 2 and is numeric and has a name in the possible values of y_var. NA within a vector indicates that the data range should be used. for ggplot2, y_lim is only used to exclude values outside that range and is ignored if the data span a narrower range.
Examples
if (FALSE) { # interactive()
mm <- metab_night(specs(mm_name('night')), data=data_metab('10', day_start=12, day_end=36))
plot_metab_preds(mm)
}