Deprecated functions in streamMetabolizer
Source:R/streamMetabolizer-deprecated.R
streamMetabolizer-deprecated.RdThese functions are provided for compatibility with older versions of streamMetabolizer only, and may be defunct as soon as the next release.
Details
calc_DO_deficit()is superseded by subtractingDO.obsfrom the output ofcalc_DO_sat().calc_DO_at_sat()is superseded bycalc_DO_sat().calc_is_daytime()is deprecated.calc_sun_rise_set()is deprecated.
These functions are defunct and will error when called:
lookup_google_timezone()is superseded bylookup_timezone().