Skip to contents

[Deprecated]

calc_is_daytime() is deprecated.

Usage

calc_is_daytime(datetimes, lat)

Arguments

datetimes

A POSIXct or POSIXlt vector in solar time. See DateTimeClasses().

lat

A numeric scalar giving the site latitude. Use negative values south of the equator and positive values north of it.

Value

A logical vector with the same length as datetimes.

Details

Returns a logical vector indicating whether each datetime occurs during daylight hours.

Author

Luke A. Winslow

Examples

if (FALSE) { # interactive()
# Warning: this function is deprecated.
calc_is_daytime(
  datetimes = as.POSIXct(paste("2013-03-31", c("1:00", "11:00"))),
  lat = 40.75
)
}