Calculate photosynthetically active radiation (PAR) for a series of date-times and site coordinates.
Arguments
- solar.time
Mean solar time, as required for input to metabolism models. See
mm_data()andcalc_solar_time().- latitude
Numeric value or vector indicating the site latitude in decimal degrees (never radians or deg-min-sec, no matter what
formatis) between -90 (South Pole) and 90 (North Pole).- longitude
Numeric, in degrees, either positive and unitted ("degE" or "degW") or with sign indicating direction (positive = East), describing location of the site.
- max.PAR
Numeric or unitted_numeric: the PAR (umol m^-2 s^-1) that each day should reach at peak light.
- attach.units
Deprecated. A logical. Should the returned vector be a unitted object?
Examples
solar.time <- lubridate::force_tz(as.POSIXct('2016-09-27 12:00'), 'UTC')
calc_light(solar.time, 40, -120)
#> [1] 1720.981