Convert a decimal day of year to a date
Usage
convert_doyhr_to_date(
doyhr,
year,
tz = "UTC",
origin = as.POSIXct("1970-01-01 00:00:00", tz = "UTC"),
...
)Convert a decimal day of year to a date
convert_doyhr_to_date(
doyhr,
year,
tz = "UTC",
origin = as.POSIXct("1970-01-01 00:00:00", tz = "UTC"),
...
)