Use USGS API (USGS Elevation Point Query Service) to determine approximate local elevation
Source:R/lookup_usgs_elevation.R
lookup_usgs_elevation.RdThis is meant to supply an APPROXIMATE elevation, with no guarantees on precision or on the lifetime of the API service used by the function. The lookup uses the JSON response from the service.
Arguments
- latitude
Degrees latitude (positive for north) of the location to look up.
- longitude
Degrees longitude (positive for east) of the location to look up.
- units
A single string specifying the elevation units. Accepts
"m","meters","ft", or"feet", case-insensitively.- timeout
A single positive number giving the request timeout in seconds.
- max_tries
A single positive integer giving the maximum number of request attempts.